@@ -331,7 +331,8 @@ alter table items add publickey               varchar(64)             DEFAULT ''
 alter table items add privatekey              varchar(64)             DEFAULT ''      NOT NULL;
 alter table items add mtime                   integer         DEFAULT '0'     NOT NULL;
 
-UPDATE items SET units='Bps' WHERE type=9 AND units='bps';CREATE TABLE maintenances_groups (
+UPDATE items SET units='Bps' WHERE type=9 AND units='bps';
+CREATE TABLE maintenances_groups (
         maintenance_groupid             bigint          DEFAULT '0'     NOT NULL,
         maintenanceid           bigint          DEFAULT '0'     NOT NULL,
         groupid         bigint          DEFAULT '0'     NOT NULL,
